Function designed to extract the fixed effects from an
MCMCglmm model object. Can either extract all samples from the
fixed effects posteriors or return the posterior means.
An MCMCglmm model object to extract the effects from
A character string indicating whether to extract all posterior samples or the mean of the posteriors. Defaults to "all".
Arguments passed on to the worker function.
A matrix of the fixed effects