These methods, suggested by David Luke Thiessen on Stack Exchange, provide support for linear quantile mixed models. They have not been carefully tested - please check output carefully and report problems!
# S3 method for lqmm
tidy(x, conf.int = FALSE, conf.level = 0.95, ...)# S3 method for lqmm
glance(x, ...)
An object of class merMod, such as those from lmer,
glmer, or nlmer
whether to include a confidence interval
confidence level for CI
Additional arguments (passed to confint.merMod for tidy; augment_columns for augment; ignored for glance)