All tidying methods return a data.frame without rownames.
The structure depends on the method chosen.
When effects="fixed" (the default), tidy.stanreg returns
one row for each coefficient, with three columns:
- term
The name of the corresponding term in the model.
- estimate
A point estimate of the coefficient (posterior median).
- std.error
A standard error for the point estimate based on
mad. See the Uncertainty estimates section in
print.stanreg for more details.
For models with group-specific parameters (e.g., models fit with
stan_glmer), setting effects="ran_vals"
selects the group-level parameters instead of the non-varying regression
coefficients. Addtional columns are added indicating the level and
group. Specifying effects="ran_pars" selects the
standard deviations and (for certain models) correlations of the group-level
parameters.
Setting effects="auxiliary" will select parameters other than those
included by the other options. The particular parameters depend on which
rstanarm modeling function was used to fit the model. For example, for
models fit using stan_glm the overdispersion
parameter is included if effects="aux", for
stan_lm the auxiliary parameters include the residual
SD, R^2, and log(fit_ratio), etc.
glance returns one row with the columns
- algorithm
The algorithm used to fit the model.
- pss
The posterior sample size (except for models fit using
optimization).
- nobs
The number of observations used to fit the model.
- sigma
The square root of the estimated residual variance, if
applicable. If not applicable (e.g., for binomial GLMs), sigma will
be given the value 1 in the returned object.
If looic=TRUE, then the following additional columns are also
included:
- looic
The LOO Information Criterion.
- elpd_loo
The expected log predictive density (elpd_loo = -2 *
looic).
- p_loo
The effective number of parameters.